from . import utils, masking, dvd, cursed # noqa F401

# Alias for script compatibility
batchindex = utils.batch_index

# aliases for shits and giggles
voodoo = cursed
